@@ -8,6 +8,7 @@ from typing import Any, Callable, Optional
 from quickbuild.endpoints import (
     Agents,
     Audits,
+    Authorizations,
     Builds,
     Changes,
     Configurations,
@@ -18,6 +19,7 @@ from quickbuild.endpoints import (
     Measurements,
     Memberships,
     Nodes,
+    Profiles,
     Reports,
     Requests,
     Resources,
@@ -50,6 +52,7 @@ class QuickBuild:
 
         self.agents = Agents(self)
         self.audits = Audits(self)
+        self.authorizations = Authorizations(self)
         self.builds = Builds(self)
         self.changes = Changes(self)
         self.configurations = Configurations(self)
@@ -60,6 +63,7 @@ class QuickBuild:
         self.measurements = Measurements(self)
         self.memberships = Memberships(self)
         self.nodes = Nodes(self)
+        self.profiles = Profiles(self)
         self.reports = Reports(self)
         self.requests = Requests(self)
         self.resources = Resources(self)
